##  Guidelines and Best Practices
  * When you start working with SAP LeanIX, use the fact sheet type only when it adds value for your organization, or there is a clear expectation to reflect business contexts in your EA work. Keep in mind the maintenance effort.
  * Business context is a vast category - it is recommendable to choose at least one fact sheet subtype that reflects the most common and known approach to structure the business in your organization. E.g., if you have a well-established business process management (BPM), use the process subtype. The choice can also depend on the type of business, e.g., B2C businesses might tend more to customer journeys to reflect their business contexts than B2B companies.
  * Involve the right business owners to align on the subtype(s) and create/maintain business context fact sheet.
  * Choose two dimensions (fact sheet (sub)types) at most: Even if there is a perceived need to cover more, remember that the application owners must maintain the mapping. Getting one group right is better than having two or more incomplete or inaccurate ones.
  * Work backward and ask yourself: What would I want to see in the application matrix if I had to choose among those four dimensions?
  * Always put yourself in the shoes of application owners. What will make their lives easier? Ultimately, the more they can relate to your way of modeling, the higher your data quality is.
  * You can link different business context fact sheet subtypes if it makes sense to your organization (e.g., value stream and process).
  * If your organization uses Signavio for BPM, leverage the out-of-the-box SAP LeanIX [SAP Signavio Integration](https://help.sap.com/docs/leanix/ea/sap-signavio-integration?locale=en-US&state=PRODUCTION&version=CLOUD "The integration between SAP LeanIX and SAP Signavio enables seamless data synchronization, ensuring both systems have consistent and up-to-date information about business processes and IT systems. Learn how to set up the integration and how to map and sync data between SAP LeanIX and SAP Signavio.") to sync your data from SAP Signavio to SAP LeanIX and vice versa.


The examples below show the different modeling approaches for different archetypes of organizations.
